@@ -2,7 +2,12 @@ from .api import (
     ApplicationIn,
     ApplicationOut,
     DashboardAccessOut,
+    IntegrationIn,
+    IntegrationKeyOut,
+    IntegrationOut,
+    IntegrationUpdate,
     ListResponseApplicationOut,
+    ListResponseIntegrationOut,
     ListResponseMessageOut,
     MessageIn,
     MessageOut,
@@ -16,7 +21,12 @@ __all__ = [
     "ApplicationOut",
     "DashboardAccessOut",
     "ListResponseApplicationOut",
+    "ListResponseIntegrationOut",
     "ListResponseMessageOut",
+    "IntegrationIn",
+    "IntegrationKeyOut",
+    "IntegrationOut",
+    "IntegrationUpdate",
     "MessageIn",
     "MessageOut",
     "Svix",
@@ -25,4 +35,4 @@ __all__ = [
     "WebhookVerificationError",
 ]
 
-__version__ = "0.43.0"
+__version__ = "0.47.0"
