@@ -7,6 +7,7 @@ from .openapi_client.api.application_api import ApplicationApi
 from .openapi_client.api.authentication_api import AuthenticationApi
 from .openapi_client.api.endpoint_api import EndpointApi
 from .openapi_client.api.event_type_api import EventTypeApi
+from .openapi_client.api.integration_api import IntegrationApi
 from .openapi_client.api.message_api import MessageApi
 from .openapi_client.api.message_attempt_api import MessageAttemptApi
 from .openapi_client.api_client import ApiClient
@@ -24,10 +25,15 @@ from .openapi_client.model.endpoint_update import EndpointUpdate
 from .openapi_client.model.event_type_in import EventTypeIn
 from .openapi_client.model.event_type_out import EventTypeOut
 from .openapi_client.model.event_type_update import EventTypeUpdate
+from .openapi_client.model.integration_in import IntegrationIn
+from .openapi_client.model.integration_key_out import IntegrationKeyOut
+from .openapi_client.model.integration_out import IntegrationOut
+from .openapi_client.model.integration_update import IntegrationUpdate
 from .openapi_client.model.list_response_application_out import ListResponseApplicationOut
 from .openapi_client.model.list_response_endpoint_message_out import ListResponseEndpointMessageOut
 from .openapi_client.model.list_response_endpoint_out import ListResponseEndpointOut
 from .openapi_client.model.list_response_event_type_out import ListResponseEventTypeOut
+from .openapi_client.model.list_response_integration_out import ListResponseIntegrationOut
 from .openapi_client.model.list_response_message_attempt_endpoint_out import ListResponseMessageAttemptEndpointOut
 from .openapi_client.model.list_response_message_attempt_out import ListResponseMessageAttemptOut
 from .openapi_client.model.list_response_message_endpoint_out import ListResponseMessageEndpointOut
@@ -56,10 +62,19 @@ class ListOptions:
         return {k: v for k, v in asdict(self).items() if v is not None}
 
 
+@dataclass
+class PostOptions:
+    idempotency_key: t.Optional[str] = None
+
+    def to_dict(self) -> t.Dict[str, t.Any]:
+        return {k: v for k, v in asdict(self).items() if v is not None}
+
+
 @dataclass
 class MessageListOptions(ListOptions):
     event_types: t.Optional[t.List[str]] = None
     before: t.Optional[datetime] = None
+    channel: t.Optional[str] = None
 
 
 @dataclass
@@ -78,16 +93,24 @@ class EndpointListOptions(ListOptions):
     pass
 
 
+@dataclass
+class IntegrationListOptions(ListOptions):
+    pass
+
+
 @dataclass
 class MessageAttemptListOptions(ListOptions):
     status: t.Optional[MessageStatus] = None
     event_types: t.Optional[t.List[str]] = None
     before: t.Optional[datetime] = None
+    channel: t.Optional[str] = None
 
 
 ApiClass = t.TypeVar(
     "ApiClass",
-    bound=t.Union[AuthenticationApi, ApplicationApi, EndpointApi, EventTypeApi, MessageApi, MessageAttemptApi],
+    bound=t.Union[
+        AuthenticationApi, ApplicationApi, EndpointApi, EventTypeApi, IntegrationApi, MessageApi, MessageAttemptApi
+    ],
 )
 
 
@@ -112,15 +135,15 @@ class ApiBase(t.Generic[ApiClass]):
 class Authentication(ApiBase[AuthenticationApi]):
     _ApiClass = AuthenticationApi
 
-    def dashboard_access(self, app_id: str) -> DashboardAccessOut:
+    def dashboard_access(self, app_id: str, options: PostOptions = PostOptions()) -> DashboardAccessOut:
         with self._api() as api:
             return api.get_dashboard_access_api_v1_auth_dashboard_access_app_id_post(
-                app_id=app_id, _check_return_type=False
+                app_id=app_id, **options.to_dict(), _check_return_type=False
             )
 
-    def logout(self) -> None:
+    def logout(self, options: PostOptions = PostOptions()) -> None:
         with self._api() as api:
-            return api.logout_api_v1_auth_logout_post(_check_return_type=False)
+            return api.logout_api_v1_auth_logout_post(**options.to_dict(), _check_return_type=False)
 
 
 class Application(ApiBase[ApplicationApi]):
@@ -130,14 +153,22 @@ class Application(ApiBase[ApplicationApi]):
         with self._api() as api:
             return api.list_applications_api_v1_app_get(**options.to_dict(), _check_return_type=False)
 
-    def create(self, application_in: ApplicationIn) -> ApplicationOut:
+    def create(self, application_in: ApplicationIn, options: PostOptions = PostOptions()) -> ApplicationOut:
         with self._api() as api:
-            return api.create_application_api_v1_app_post(application_in=application_in, _check_return_type=False)
+            return api.create_application_api_v1_app_post(
+                application_in=application_in, **options.to_dict(), _check_return_type=False
+            )
 
     def get(self, app_id: str) -> ApplicationOut:
         with self._api() as api:
             return api.get_application_api_v1_app_app_id_get(app_id=app_id, _check_return_type=False)
 
+    def get_or_create(self, application_in: ApplicationIn, options: PostOptions = PostOptions()) -> ApplicationOut:
+        with self._api() as api:
+            return api.create_application_api_v1_app_post(
+                application_in=application_in, get_if_exists=True, **options.to_dict(), _check_return_type=False
+            )
+
     def update(self, app_id: str, application_in: ApplicationIn) -> ApplicationOut:
         with self._api() as api:
             return api.update_application_api_v1_app_app_id_put(
@@ -158,10 +189,10 @@ class Endpoint(ApiBase[EndpointApi]):
                 app_id=app_id, **options.to_dict(), _check_return_type=False
             )
 
-    def create(self, app_id: str, endpoint_in: EndpointIn) -> EndpointOut:
+    def create(self, app_id: str, endpoint_in: EndpointIn, options: PostOptions = PostOptions()) -> EndpointOut:
         with self._api() as api:
             return api.create_endpoint_api_v1_app_app_id_endpoint_post(
-                app_id, endpoint_in=endpoint_in, _check_return_type=False
+                app_id, endpoint_in=endpoint_in, **options.to_dict(), _check_return_type=False
             )
 
     def get(self, app_id: str, endpoint_id: str) -> EndpointOut:
@@ -188,21 +219,31 @@ class Endpoint(ApiBase[EndpointApi]):
                 app_id=app_id, endpoint_id=endpoint_id, _check_return_type=False
             )
 
-    def rotate_secret(self, app_id: str, endpoint_id: str, endpoint_secret_rotate_in: EndpointSecretRotateIn) -> None:
+    def rotate_secret(
+        self,
+        app_id: str,
+        endpoint_id: str,
+        endpoint_secret_rotate_in: EndpointSecretRotateIn,
+        options: PostOptions = PostOptions(),
+    ) -> None:
         with self._api() as api:
             return api.rotate_endpoint_secret_api_v1_app_app_id_endpoint_endpoint_id_secret_rotate_post(
                 app_id=app_id,
                 endpoint_id=endpoint_id,
                 endpoint_secret_rotate_in=endpoint_secret_rotate_in,
+                **options.to_dict(),
                 _check_return_type=False,
             )
 
-    def recover(self, app_id: str, endpoint_id: str, recover_in: RecoverIn) -> None:
+    def recover(
+        self, app_id: str, endpoint_id: str, recover_in: RecoverIn, options: PostOptions = PostOptions()
+    ) -> None:
         with self._api() as api:
             api.recover_failed_webhooks_api_v1_app_app_id_endpoint_endpoint_id_recover_post(
                 app_id=app_id,
                 endpoint_id=endpoint_id,
                 recover_in=recover_in,
+                **options.to_dict(),
                 _check_return_type=False,
             )
 
@@ -240,9 +281,11 @@ class EventType(ApiBase[EventTypeApi]):
         with self._api() as api:
             return api.list_event_types_api_v1_event_type_get(**options.to_dict(), _check_return_type=False)
 
-    def create(self, event_type_in: EventTypeIn) -> EventTypeOut:
+    def create(self, event_type_in: EventTypeIn, options: PostOptions = PostOptions()) -> EventTypeOut:
         with self._api() as api:
-            return api.create_event_type_api_v1_event_type_post(event_type_in=event_type_in, _check_return_type=False)
+            return api.create_event_type_api_v1_event_type_post(
+                event_type_in=event_type_in, **options.to_dict(), _check_return_type=False
+            )
 
     def get(self, event_type_name: str) -> EventTypeOut:
         with self._api() as api:
@@ -263,6 +306,54 @@ class EventType(ApiBase[EventTypeApi]):
             )
 
 
+class Integration(ApiBase[IntegrationApi]):
+    _ApiClass = IntegrationApi
+
+    def list(
+        self, app_id: str, options: IntegrationListOptions = IntegrationListOptions()
+    ) -> ListResponseIntegrationOut:
+        with self._api() as api:
+            return api.list_integrations_api_v1_app_app_id_integration_get(
+                app_id=app_id, **options.to_dict(), _check_return_type=False
+            )
+
+    def create(self, app_id: str, integ_in: IntegrationIn, options: PostOptions = PostOptions()) -> IntegrationOut:
+        with self._api() as api:
+            return api.create_integration_api_v1_app_app_id_integration_post(
+                app_id, integration_in=integ_in, **options.to_dict(), _check_return_type=False
+            )
+
+    def get(self, app_id: str, integ_id: str) -> IntegrationOut:
+        with self._api() as api:
+            return api.get_integration_api_v1_app_app_id_integration_integ_id_get(
+                app_id=app_id, integ_id=integ_id, _check_return_type=False
+            )
+
+    def update(self, app_id: str, integ_id: str, integ_update: IntegrationUpdate) -> IntegrationOut:
+        with self._api() as api:
+            return api.update_integration_api_v1_app_app_id_integration_integ_id_put(
+                app_id=app_id, integ_id=integ_id, integration_update=integ_update, _check_return_type=False
+            )
+
+    def delete(self, app_id: str, integ_id: str) -> None:
+        with self._api() as api:
+            return api.delete_integration_api_v1_app_app_id_integration_integ_id_delete(
+                app_id=app_id, integ_id=integ_id, _check_return_type=False
+            )
+
+    def get_key(self, app_id: str, integ_id: str) -> IntegrationKeyOut:
+        with self._api() as api:
+            return api.get_integration_key_api_v1_app_app_id_integration_integ_id_key_get(
+                app_id=app_id, integ_id=integ_id, _check_return_type=False
+            )
+
+    def rotate_key(self, app_id: str, integ_id: str, options: PostOptions = PostOptions()) -> IntegrationKeyOut:
+        with self._api() as api:
+            return api.rotate_integration_key_api_v1_app_app_id_integration_integ_id_key_rotate_post(
+                app_id=app_id, integ_id=integ_id, **options.to_dict(), _check_return_type=False
+            )
+
+
 class Message(ApiBase[MessageApi]):
     _ApiClass = MessageApi
 
@@ -272,10 +363,10 @@ class Message(ApiBase[MessageApi]):
                 app_id=app_id, **options.to_dict(), _check_return_type=False
             )
 
-    def create(self, app_id: str, message_in: MessageIn) -> MessageOut:
+    def create(self, app_id: str, message_in: MessageIn, options: PostOptions = PostOptions()) -> MessageOut:
         with self._api() as api:
             return api.create_message_api_v1_app_app_id_msg_post(
-                app_id=app_id, message_in=message_in, _check_return_type=False
+                app_id=app_id, message_in=message_in, **options.to_dict(), _check_return_type=False
             )
 
     def get(self, app_id: str, msg_id: str) -> MessageOut:
@@ -302,10 +393,10 @@ class MessageAttempt(ApiBase[MessageAttemptApi]):
                 app_id=app_id, msg_id=msg_id, attempt_id=attempt_id, _check_return_type=False
             )
 
-    def resend(self, app_id: str, msg_id: str, endpoint_id: str) -> None:
+    def resend(self, app_id: str, msg_id: str, endpoint_id: str, options: PostOptions = PostOptions()) -> None:
         with self._api() as api:
             return api.resend_webhook_api_v1_app_app_id_msg_msg_id_endpoint_endpoint_id_resend_post(
-                app_id=app_id, msg_id=msg_id, endpoint_id=endpoint_id, _check_return_type=False
+                app_id=app_id, msg_id=msg_id, endpoint_id=endpoint_id, **options.to_dict(), _check_return_type=False
             )
 
     def list_attempted_messages(
@@ -360,6 +451,10 @@ class Svix:
     def event_type(self) -> EventType:
         return EventType(self._configuration)
 
+    @property
+    def integration(self) -> Integration:
+        return Integration(self._configuration)
+
     @property
     def message(self) -> Message:
         return Message(self._configuration)
