@@ -17,10 +17,11 @@
 from svix.openapi_client.api.application_api import ApplicationApi
 from svix.openapi_client.api.authentication_api import AuthenticationApi
 from svix.openapi_client.api.endpoint_api import EndpointApi
+from svix.openapi_client.api.environment_api import EnvironmentApi
+from svix.openapi_client.api.environment_settings_api import EnvironmentSettingsApi
 from svix.openapi_client.api.event_type_api import EventTypeApi
 from svix.openapi_client.api.health_api import HealthApi
+from svix.openapi_client.api.integration_api import IntegrationApi
 from svix.openapi_client.api.message_api import MessageApi
 from svix.openapi_client.api.message_attempt_api import MessageAttemptApi
-from svix.openapi_client.api.organization_api import OrganizationApi
-from svix.openapi_client.api.organization_settings_api import OrganizationSettingsApi
 from svix.openapi_client.api.statistics_api import StatisticsApi
