@@ -34,21 +34,27 @@ from svix.openapi_client.model.endpoint_stats import EndpointStats
 from svix.openapi_client.model.endpoint_update import EndpointUpdate
 from svix.openapi_client.model.endpoint_updated_event import EndpointUpdatedEvent
 from svix.openapi_client.model.endpoint_updated_event_data import EndpointUpdatedEventData
+from svix.openapi_client.model.environment_in import EnvironmentIn
+from svix.openapi_client.model.environment_out import EnvironmentOut
+from svix.openapi_client.model.environment_settings_out import EnvironmentSettingsOut
 from svix.openapi_client.model.event_example_in import EventExampleIn
 from svix.openapi_client.model.event_type_example_out import EventTypeExampleOut
 from svix.openapi_client.model.event_type_in import EventTypeIn
 from svix.openapi_client.model.event_type_out import EventTypeOut
 from svix.openapi_client.model.event_type_schema_in import EventTypeSchemaIn
 from svix.openapi_client.model.event_type_update import EventTypeUpdate
-from svix.openapi_client.model.export_organization_out import ExportOrganizationOut
 from svix.openapi_client.model.font_size_config import FontSizeConfig
 from svix.openapi_client.model.http_validation_error import HTTPValidationError
 from svix.openapi_client.model.http_error_out import HttpErrorOut
-from svix.openapi_client.model.import_organization_in import ImportOrganizationIn
+from svix.openapi_client.model.integration_in import IntegrationIn
+from svix.openapi_client.model.integration_key_out import IntegrationKeyOut
+from svix.openapi_client.model.integration_out import IntegrationOut
+from svix.openapi_client.model.integration_update import IntegrationUpdate
 from svix.openapi_client.model.list_response_application_out import ListResponseApplicationOut
 from svix.openapi_client.model.list_response_endpoint_message_out import ListResponseEndpointMessageOut
 from svix.openapi_client.model.list_response_endpoint_out import ListResponseEndpointOut
 from svix.openapi_client.model.list_response_event_type_out import ListResponseEventTypeOut
+from svix.openapi_client.model.list_response_integration_out import ListResponseIntegrationOut
 from svix.openapi_client.model.list_response_message_attempt_endpoint_out import ListResponseMessageAttemptEndpointOut
 from svix.openapi_client.model.list_response_message_attempt_out import ListResponseMessageAttemptOut
 from svix.openapi_client.model.list_response_message_endpoint_out import ListResponseMessageEndpointOut
@@ -63,7 +69,6 @@ from svix.openapi_client.model.message_endpoint_out import MessageEndpointOut
 from svix.openapi_client.model.message_in import MessageIn
 from svix.openapi_client.model.message_out import MessageOut
 from svix.openapi_client.model.message_status import MessageStatus
-from svix.openapi_client.model.portal_settings_out import PortalSettingsOut
 from svix.openapi_client.model.recover_in import RecoverIn
 from svix.openapi_client.model.settings_in import SettingsIn
 from svix.openapi_client.model.settings_out import SettingsOut
